//
//  SingleMessageQueryView.swift
//  SampleApp
//
//  Created by Manuchet Rungraksa on 1/9/2565 BE.
//  Copyright © 2565 BE David Zhang. All rights reserved.
//

import SwiftUI
import AmitySDK

struct SingleMessageQueryView: View {
    @State var messageId = ""
    @State var messageInfo = ""
    
    let viewModel = MessageQueryViewModel()
    
    var body: some View {
        VStack {
            TextField("Enter Message Id", text: $messageId)
                .autocapitalization(.none)
                .padding()
                .frame(height: 50)
                .background(Color(UIColor.systemGroupedBackground))
            
            Button(action: {
                self.viewModel.fetchMessageInfo(id: self.messageId) { info in
                    self.messageInfo = info
                }
                
            }) {
                Text("Query Message")
            }
            .frame(width: 200, height: 40)
            .foregroundColor(Color.white)
            .background(Color.blue)
            .cornerRadius(16)
            .padding(.top, 20)
            
            Text(messageInfo)
                .padding(.top, 16)
            
            Spacer()
        }.padding()
            .navigationBarTitle("Get Message", displayMode: .inline)
        
    }
}

struct SingleMessageQueryView_Previews: PreviewProvider {
    static var previews: some View {
        SingleMessageQueryView()
    }
}

class MessageQueryViewModel {
    
    var token: AmityNotificationToken?
    let messageRepo = AmityMessageRepository(client: AmityManager.shared.client!)
    var fetchedMessage: AmityObject<AmityMessage>?
    
    func fetchMessageInfo(id: String, completion: @escaping (String) -> Void) {
        fetchedMessage = messageRepo.getMessage(id)
        token = fetchedMessage?.observe { liveObject, error in
            let dataStatus = liveObject.dataStatus.description
            if let err = error {
                completion("Error Occurred: \(err.localizedDescription) Data Status: \(dataStatus)")
            } else {
                let modelDescription = liveObject.snapshot?.modelDescription
                completion(modelDescription ?? "")
            }
        }
    }
}
