//
//  StoryItemView.swift
//  SampleApp
//
//  Created by Manuchet Rungraksa on 4/12/2566 BE.
//  Copyright © 2566 BE David Zhang. All rights reserved.
//

import Foundation
import SwiftUI

struct StoryItemView: View {
    typealias Action = (() -> Void)?
    
    var model: StoryModel
    var hardDeleteAction: (() -> Void)?
    var softDeleteAction: (() -> Void)?
    var markAsSeen: (() -> Void)?
    var markLinkAsClicked: (() -> Void)?
    
    @State var showAction: Bool = false
    
    init(model: StoryModel,
         hardDeleteAction: Action,
         softDeleteAction: Action,
         markAsSeen: Action,
         markLinkAsClicked: Action) {
        self.model = model
        self.hardDeleteAction = hardDeleteAction
        self.softDeleteAction = softDeleteAction
        self.markAsSeen = markAsSeen
        self.markLinkAsClicked = markLinkAsClicked
    }
    
    var body: some View {
        VStack {
            
            VStack(spacing: 5) {
                
                let data = model.getPreviewData()
                
                ForEach(0..<data.count, id: \.self) { index in
                    let item = data[index]
                    CardTextView(key: item.0, value: item.1, lineLimit: nil)
                }
                
            }
            .padding([.top, .bottom], 16)
        }
        .background(Color(.pastelBlue))
        .cornerRadius(20)
        .shadow(color: Color.gray.opacity(0.6), radius: 8, x: 0, y: 0)
        .padding([.top, .bottom], 8)
        .onTapGesture {
            showAction.toggle()
        }
        .actionSheet(isPresented: $showAction, content: {
            return ActionSheet(title: Text("Choose Actions"), message: Text("What do you want to do?"), buttons: getAllActions())
        })
    }
    
    func getAllActions() -> [ActionSheet.Button] {
        var actions = [ActionSheet.Button]()
        
        actions.append(.default(Text("Hard delete"), action: {
            hardDeleteAction?()
        }))
        
        actions.append(.default(Text("Soft delete"), action: {
            softDeleteAction?()
        }))
        
        actions.append(.default(Text("Mark Seen"), action: {
            markAsSeen?()
        }))
        
//        actions.append(.default(Text("Mark link as clicked"), action: {
//            markLinkAsClicked?()
//        }))
        
        // Default dismiss action
        actions.append(.cancel(Text("Dismiss")))
        
        return actions
    }
}
