//
//  StoryModel.swift
//  SampleApp
//
//  Created by Manuchet Rungraksa on 4/12/2566 BE.
//  Copyright © 2566 BE David Zhang. All rights reserved.
//

import Foundation
import AmitySDK

struct StoryModel: Identifiable, Equatable {
    
    let storyObject: AmityStory
    
    static func == (lhs: StoryModel, rhs: StoryModel) -> Bool {
        return lhs.id == rhs.id
    }
    
    var id: String {
        return storyId
    }
    
    var storyId: String
    var creatorId: String
    var dataType: String
    var targetId: String
    var targetType: String
    var data: [String: Any]?
    var items: [AmityStoryItem]
    var expiresAt: Date
    var isDeleted: Bool
    var syncState: AmitySyncState
    var videoResolution: [AmityVideoResolution]
    var imageDisplayMode: String?
    
    let createdAt: Date
    let metadata: [String: Any]?
    
    let impression: Int
    let reach: Int
    let isSeen: Bool
    
    init(story: AmityStory) {
        storyObject = story
        storyId = story.storyId
        creatorId = story.creatorId
        dataType = story.dataType
        targetId = story.targetId
        targetType = story.targetType
        data = story.data
        items = story.items
        expiresAt = story.expiresAt
        createdAt = story.createdAt
        metadata = story.metadata
        isDeleted = story.isDeleted
        syncState = story.syncState
        videoResolution = story.availableResolution()
        impression = story.impression
        reach = story.reach
        isSeen = story.isSeen
        imageDisplayMode = story.getImageDisplayMode()?.rawValue
    }
    
    func getStoryObject() -> AmityStory {
        return storyObject
    }
    
    func getPreviewData() -> [(key: String, value: String)] {
        return [
            ("Story Id:", storyId),
            ("Creator Public ID:", creatorId),
            ("Data Type:", dataType),
            ("Target Type:", targetType),
            ("Target Id:", targetId),
            ("MetaData", metadata?.description ?? ""),
            ("Created At:", "\(createdAt)"),
            ("Data:", data?.description ?? ""),
            ("Items:", "\(items.map({$0.displayedString}))"),
            ("Expires At:", "\(expiresAt)"),
            ("Is Deleted:", "\(isDeleted)"),
            ("Sync State:", "\(syncState)"),
            ("Video Resolution:", "\(videoResolution)"),
            ("Impression:", "\(impression)"),
            ("Reach:", "\(reach)"),
            ("IsSeen:", "\(isSeen)"),
            ("Image Display mode:", "\(imageDisplayMode ?? "")")
        ]
    }
}

extension AmityStoryItem {
    var displayedString: String {
        var displayedString = "Type: \(getType())"
        
        if let url = getData()["url"] as? String {
            displayedString.append(", url: \(url)")
        }
        
        if let customText = getData()["customText"] as? String {
            displayedString.append(", customText: \(customText)")
        }
        return displayedString
    }
}
