//
//  MessageRealTimeEventManager.swift
//  SampleApp
//
//  Created by Manuchet Rungraksa on 24/11/2565 BE.
//  Copyright © 2565 BE David Zhang. All rights reserved.
//

import Foundation
import AmitySDK

class MessageRealTimeEventManager {
    
    enum Element {
        case header
    }
    
    var messageToken: AmityNotificationToken?
    var messageRepo = AmityMessageRepository(client: AmityManager.shared.client!)
    
    var message: AmityMessage
    var elements = [MessageRealTimeEventManager.Element]()
    
    var observeMessageChanges: (() -> Void)?
    
    init(message: AmityMessage) {
        self.message = message
        self.elements = [.header]
    }
    
    func subscribeEvent(completion: ((Bool) -> Void)?) {
        observeCurrentMessage()
        
        message.subscribeEvent { success, error in
            completion?(success)

            Log.add(info: "Message Subscribe Event: \(success) Error: \(String(describing: error))")
        }
    }
    
    func unsubscribeEvent(completion: ((Bool) -> Void)?) {
        
        message.unsubscribeEvent { success, error in
            completion?(success)
            Log.add(info: "Message UnSubscribe Event: \(success) Error: \(String(describing: error))")
        }
    }
    
    func observeCurrentMessage() {
        messageToken?.invalidate()
        messageToken = messageRepo.getMessage(message.messageId).observe { [weak self] liveMessage, error in
            guard let message = liveMessage.snapshot else { return }

            self?.message = message
            self?.observeMessageChanges?()
        }
    }
    
    deinit {
        messageToken?.invalidate()
    }
}
