//
//  TestController.swift
//  SampleApp
//
//  Created by Nishan Niraula on 10/15/20.
//  Copyright © 2020 David Zhang. All rights reserved.
//

import Foundation
import UIKit
import AmitySDK
import Combine
import SwiftUI
import MobileCoreServices
import AVKit


// NOTE:
// Ignore stuffs in this class. This class is just for quick testing of sdk stuffs inside sample app.
class TestController: UIViewController {
    let buttonStack = UIStackView(frame: .zero)
    
    let client = AmityManager.shared.client!
    
    var token: AmityNotificationToken?
    
    let userRepo = AmityUserRepository(client: AmityManager.shared.client!)
    let commRepo = AmityCommunityRepository(client: AmityManager.shared.client!)
    let commentRepo = AmityCommentRepository(client: AmityManager.shared.client!)
    let postRepo = AmityPostRepository(client: AmityManager.shared.client!)
    let channelRepo = AmityChannelRepository(client: AmityManager.shared.client!)
    let messageRepo = AmityMessageRepository(client: AmityManager.shared.client!)
    let fileRepo = AmityFileRepository(client: AmityManager.shared.client!)
    let subChannelRepo = AmitySubChannelRepository(client: AmityManager.shared.client!)
    let reactionRepo = AmityReactionRepository(client: AmityManager.shared.client!)
    let userPresenceRepo = AmityUserPresenceRepository(client: AmityManager.shared.client!)
    let channelPresenceRepo = AmityChannelPresenceRepository(client: AmityManager.shared.client!)
    let storyRepo = AmityStoryRepository(client: AmityManager.shared.client!)
    
    var disposeBag: Set<AnyCancellable> = []
    
    var label = UILabel()
    
    override func loadView() {
        view = UIView()
        view.backgroundColor = .white
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        AmityLog.logLevel = .all        
        
        setupViews()
    }
    
    @objc func onButton1Tap() {
        showVideoPicker()
    }
    
    @objc func onButton2Tap() {
    }
        
    @objc func onButton3Tap() {
    }
    
    @objc func onButton4Tap() {
    }
        
    func setupViews() {
        
        let button1 = UIBarButtonItem(title: "A1", style: .plain, target: self, action: #selector(onButton1Tap))
        let button2 = UIBarButtonItem(title: "A2", style: .plain, target: self, action: #selector(onButton2Tap))
        let button3 = UIBarButtonItem(title: "A3", style: .plain, target: self, action: #selector(onButton3Tap))
        let button4 = UIBarButtonItem(title: "A4", style: .plain, target: self, action: #selector(onButton4Tap))
        
        self.navigationItem.rightBarButtonItems = [button1, button2, button3, button4]
    }
    
    private func showVideoPicker() {
        let videoPickerAction = UIAlertAction(title: "Photo Album", style: .default) { _ in
            guard UIImagePickerController.isSourceTypeAvailable(.photoLibrary) else { return }
            let videoPicker = UIImagePickerController()
            videoPicker.sourceType = .photoLibrary
            videoPicker.mediaTypes = [UTType.movie.identifier]
            videoPicker.videoExportPreset = AVAssetExportPresetPassthrough
            videoPicker.delegate = self
            self.present(videoPicker, animated: true, completion: nil)
        }
        
        let alertController = UIAlertController()
        alertController.addAction(videoPickerAction)
        alertController.addAction(UIAlertAction(title: "Cancel", style: .destructive))
        present(alertController, animated: true)
        
    }
}


extension TestController: UINavigationControllerDelegate, UIImagePickerControllerDelegate {
    
    func imagePickerController(_ picker: UIImagePickerController, didFinishPickingMediaWithInfo info: [UIImagePickerController.InfoKey: Any]) {
        
        if let mediaType = info[.mediaType] as? String {
            switch mediaType {
            case UTType.image.identifier:
                break
            case UTType.movie.identifier:
                if let videoUrl = info[.mediaURL] as? URL {
                    DispatchQueue.main.async { [weak self] in
                        picker.dismiss(animated: true) {
                            self?.uploadVideo(from: videoUrl)
                        }
                    }
                }
            default:
                break
            }
        }
        
    }
    
    func uploadVideo(from: URL) {
        Task {
            do {
                let item = AmityHyperLinkItem(url: "www.medium.com", customText: nil)
                let options = AmityVideoStoryCreateOptions(targetType: .community, tartgetId: "655c876216f3af7d5613dd87", videoFileURL: from, metadata: nil, items: [item])

                try await storyRepo.createVideoStory(options: options)
            } catch {
                print(error)
            }
        }
    }
    
}
